{
  Autor: Michael Springwald

  Erstellt: Samstag der 01.März.2008
  Updates:

}

unit plXine;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, xine;

const
  plSOpen  = 0;
  plSPlay  = 1;
  plSPause = 2;
  plSStop  = 3;
  
type

  { TPLXine }

  TPLXine = class
  private

  protected

  public
    PlayTime, PlayPos, PlayLen:Integer;
    CurrFileName:String;
    myXine : Pxine_t;

    ao_driver:Pxine_ao_driver_t;
    myXStream : Pxine_stream_t;
    queue: Pxine_event_queue_t;
    PlayStatus:Integer;

    constructor Create(const aAutoInit:Boolean = True);
    destructor Destroy; override;
    
    procedure init;
    procedure FileOpen(const aFileName:String);
    procedure play;
    procedure Stop;
    procedure Pause;
    
    procedure Status(var aPos, aTime, aLen:Integer);
    procedure SetInfo;
    
    function GetLen:String;
    function GetCurrTime(const aCurr2Time:Boolean = False):String;
    
    function GetFileExt:String;

  published

  end; // TPLXine


implementation

{ TPLXine }

constructor TPLXine.Create(const aAutoInit:Boolean = True);
begin
  inherited Create;
  if aAutoInit then init;
end; // TPLXine.Create

destructor TPLXine.Destroy;
begin
  inherited Destroy;
end; // TPLXine.Destroy

procedure TPLXine.init;
begin
  myXine := xine_new();
  xine_config_load(myXine,PChar('.xine/config'));
  xine_init(myXine);
  ao_driver := xine_open_audio_driver(myXine,'alsa',Nil);
  myXStream := xine_stream_new(myXine,ao_driver,nil);
  queue := xine_event_new_queue (myXStream);
end; // TPLXine.init

procedure TPLXine.FileOpen(const aFileName: String);
begin
  CurrFileName:=aFileName;
  xine_open(myXStream,PChar(aFileName));
end; // TPLXine.FileOpen

procedure TPLXine.play;
begin
   if (xine_get_param(myXStream,XINE_PARAM_SPEED) <> XINE_SPEED_PAUSE) then
   begin
       xine_play(myXStream,0,0);
   end;
   xine_set_param(myXStream,XINE_PARAM_SPEED,XINE_SPEED_NORMAL);
end; // TPLXine.play

procedure TPLXine.Stop;
begin
  xine_stop(myXStream);
end; // TPLXine.Stop

procedure TPLXine.Pause;
begin
  if PlayStatus = plSPause then begin
    PlayStatus:=plSPlay;
    play;
  end
  else begin
    PlayStatus:=plSPause;
    xine_set_param(myXStream,XINE_PARAM_SPEED,XINE_SPEED_PAUSE);
  end;

end; // TPLXine.Pause

procedure TPLXine.Status(var aPos, aTime, aLen: Integer);
var
  zpos, ztime, zlength: Integer;
begin
  xine_get_pos_length(myXStream,@zpos,@ztime,@zlength);
  apos:=zPos; aTime:=ztime; aLen:=zlength;
end;

procedure TPLXine.SetInfo;
begin
  Status(playpos,playtime,PlayLen);
end; // TPLXine.SetInfo

function TPLXine.GetLen: String;
var
  sLen:String;
  aMin, aSek:Integer;
begin

  aSek:=(PlayLen div 1000) mod 60;
  aMin:=(PlayLen div 60000) mod 60;
  
  sLen:=Format('%.2D:%.2D',[aMin, aSek]);
  result:=sLen;
end; // TPLXine.GetLen

function TPLXine.GetCurrTime(const aCurr2Time:Boolean = False): String;
var
  s:String;
  aMin, aSek, aT:Integer;
begin
  if not aCurr2Time then
    aT:=PlayTime
  else
    at:=PlayLen-PlayTime;
    
  aSek:=(aT div 1000) mod 60;
  aMin:=(aT div 60000) mod 60;

  s:=Format('%.2D:%.2D',[aMin, aSek]);
  result:=s;
end; // TPLXine.GetCurrTime

function TPLXine.GetFileExt: String;
begin
  result:=ExtractFileExt(CurrFileName);
end; // TPLXine.GetFileTyp

end.

